agentle.mcp.session\_management.session\_manager
================================================

.. automodule:: agentle.mcp.session_management.session_manager

   
   .. rubric:: Functions

   .. autosummary::
   
      abstractmethod
   
   .. rubric:: Classes

   .. autosummary::
   
      ABC
      Any
      SessionManager
   